;; Generated package description from cobol-mode.el  -*- no-byte-compile: t -*-
(define-package "cobol-mode" "1.0.0.0.20210327.33255" "Mode for editing COBOL code" '((cl-lib "0.5")) :url "https://elpa.gnu.org/packages/cobol-mode.html" :keywords '("languages") :authors '(("Edward Hart" . "edward.dan.hart@gmail.com")) :maintainer '("Edward Hart" . "edward.dan.hart@gmail.com"))
